"""ToolRegistry Hub Server module.

This module provides FastAPI and MCP server implementations for ToolRegistry Hub tools.
It automatically exposes all available tools as REST API endpoints and MCP tools.

Example:
    >>> from toolregistry_hub.server.main import app, mcp
    >>> # Use app for FastAPI server
    >>> # Use mcp for MCP server
"""

# from .main import app, mcp

# __all__ = ["app", "mcp"]